import { GamepadEventEmitter } from '@gamepad/core';
import joycon from '@gamepad/plugin-joycon';
export class DeckdeckgoGamepad {
    componentWillLoad() {
        this.deck = document.querySelector('deckgo-deck');
        this.gamepad = new GamepadEventEmitter({
            plugins: [
                joycon()
            ]
        });
    }
    componentDidUnload() {
        this.deck = undefined;
        this.gamepad.unsubscribe();
    }
    async gamepadButtonDownHandler(event) {
        switch (event.detail.code) {
            case 'Y': return this.slideNext();
            case 'A': return this.slidePrev();
            case 'X':
            case 'LStick':
            case 'RStick':
                return this.playVideo();
            case 'Screenshot':
            case 'Home':
                return this.toggleFullScreen();
        }
    }
    async gamepadAxisChangeHandler(event) {
        clearInterval(this.loop);
        const interval = 200;
        const x = event.detail.x;
        if (x !== 0) {
            if (x === 1) {
                this.slideNext(true);
                this.loop = setInterval(() => this.slideNext(true), interval);
            }
            if (x === -1) {
                this.slidePrev(true);
                this.loop = setInterval(() => this.slidePrev(true), interval);
            }
        }
    }
    slideNext(skip = false) {
        if (!this.deck)
            return;
        this.deck.slideNext(!skip);
    }
    slidePrev(skip = false) {
        if (!this.deck)
            return;
        this.deck.slidePrev(!skip);
    }
    toggleFullScreen() {
        if (!this.deck)
            return;
        this.deck.toggleFullScreen();
    }
    playVideo() {
        return new Promise(async (resolve) => {
            if (!this.deck) {
                resolve();
                return;
            }
            const index = await this.deck.getActiveIndex();
            const youtubeSlideElement = document.querySelector('.deckgo-slide-container:nth-child(' + (index + 1) + ')');
            if (!youtubeSlideElement || youtubeSlideElement.tagName !== 'deckgo-slide-youtube'.toUpperCase()) {
                resolve();
                return;
            }
            await youtubeSlideElement.play();
            resolve();
        });
    }
    static get is() { return "deckgo-gamepad"; }
    static get encapsulation() { return "shadow"; }
    static get listeners() { return [{
            "name": "window:gamepadbuttondown",
            "method": "gamepadButtonDownHandler"
        }, {
            "name": "window:gamepadaxischange",
            "method": "gamepadAxisChangeHandler"
        }]; }
}
